// (C) 2019-2022 GoodData Corporation
import { invariant } from "ts-invariant";
import { isInsightWidgetDefinition, isInsightWidget, } from "@gooddata/sdk-model";
import { WidgetBaseBuilder } from "./widgetFactory.js";
/**
 * @alpha
 */
export class InsightWidgetBuilder extends WidgetBaseBuilder {
    item;
    validator;
    constructor(item, validator) {
        super(item, validator);
        this.item = item;
        this.validator = validator;
    }
    static for(insightWidget) {
        invariant(isInsightWidgetDefinition(insightWidget) || isInsightWidget(insightWidget), "Provided data must be IInsightWidget or IInsightWidgetDefinition!");
        return new InsightWidgetBuilder(insightWidget);
    }
    static forNew(insight) {
        const emptyInsightWidget = {
            description: "",
            drills: [],
            ignoreDashboardFilters: [],
            ignoredDrillDownHierarchies: [],
            title: "",
            type: "insight",
            insight,
        };
        return InsightWidgetBuilder.for(emptyInsightWidget);
    }
    drills = (valueOrUpdateCallback) => this.setWidgetProp("drills", valueOrUpdateCallback);
    insight = (valueOrUpdateCallback) => this.setWidgetProp("insight", valueOrUpdateCallback);
    properties = (valueOrUpdateCallback) => this.setWidgetProp("properties", valueOrUpdateCallback);
}
/**
 * @alpha
 */
export const newInsightWidget = (insight, modifications) => {
    return InsightWidgetBuilder.forNew(insight).modify(modifications).build();
};
//# sourceMappingURL=insightWidgetFactory.js.map